pub struct CloudLayer { /* private fields */ }Expand description
A descriptive cloud layer built from kind, cover, and optional base.
Implementations
Sourceimpl CloudLayer
impl CloudLayer
Sourcepub fn new(kind: CloudKind, cover: CloudCover) -> Self
pub fn new(kind: CloudKind, cover: CloudCover) -> Self
Creates a cloud layer from cloud kind and cover.
Sourcepub fn cover(&self) -> CloudCover
pub fn cover(&self) -> CloudCover
Returns the cloud cover.